@@ -1,15 +1,20 @@
 use crate::server::world::World;
-#[cfg(any(test, feature = "precise_time"))]
-use spin_sleep::SpinSleeper;
 use std::time::{SystemTime, SystemTimeError, UNIX_EPOCH};
 use std::{
     sync::atomic::{AtomicI64, Ordering},
     time::Duration,
 };
 use tokio::task::yield_now;
-#[cfg(all(not(test), not(feature = "precise_time")))]
-use tokio::time::sleep;
 
+cfg_not_precise_time! {
+    use tokio::time::sleep;
+}
+
+cfg_precise_time! {
+    use spin_sleep::SpinSleeper;
+}
+
+/// Main Loop with an interval
 #[derive(Debug)]
 pub struct GameLoop {
     date: AtomicI64,
@@ -215,7 +220,9 @@ mod tests {
         }
 
         fn update_time(&self, new_time: i64) {
+            let old = self.time();
             self.time.store(new_time, Ordering::Release);
+            assert!(new_time > old);
             assert_ne!(10, new_time);
         }
     }
