@@ -13,20 +13,19 @@ use std::{
 };
 use tokio::sync::mpsc::UnboundedSender;
 
-use crate::{
-    error::Error,
-    packet::{to_bytes, Packet},
-};
+use crate::error::{Error, Result};
+use crate::packet::{to_bytes, Packet};
 
 use super::world_socket::WriterMessage;
 
+/// Events for a WorldSession
 #[async_trait]
 pub trait WorldSession<T: Send + Sync>
 where
     Self: Sync + Send,
 {
     /// On Connection Open
-    async fn on_open(socket_tools: SocketTools, world: &'static T) -> Result<Arc<Self>, Error>;
+    async fn on_open(socket_tools: SocketTools, world: &'static T) -> Result<Arc<Self>>;
     fn socket_tools(&self) -> &SocketTools;
     async fn on_message(world_session: &Arc<Self>, world: &'static T, packet: Packet);
     /// On Connection Close
@@ -58,6 +57,14 @@ impl SocketTools {
     }
 
     /// Send a packet to the session
+    /// ## Examples
+    /// ```rust, no_run
+    /// use rollo::server::SocketTools;
+    ///
+    /// fn on_message(socket: SocketTools) {
+    ///     socket.send(1, None);
+    /// }
+    /// ```
     pub fn send(&self, cmd: u16, payload: Option<&[u8]>) {
         if !self.is_closed() {
             if let Ok(bytes) = to_bytes(cmd, payload) {
@@ -69,19 +76,38 @@ impl SocketTools {
     }
 
     /// Send Bytes(Packet) to the session
+    /// ## Examples
+    /// ```rust, no_run
+    /// use rollo::server::SocketTools;
+    /// use rollo::packet::to_bytes;
+    ///
+    /// fn on_message(socket: SocketTools) {
+    ///     let bytes = to_bytes(1, None).unwrap().freeze();
+    ///     socket.send_data(bytes);
+    /// }
+    /// ```
     pub fn send_data(&self, bytes: Bytes) {
         if !self.is_closed() && self.tx.send(WriterMessage::Bytes(bytes)).is_err() {
             log::error!("Can't send the data to the channel.");
         }
     }
 
+    /// get Latency
+    /// ## Examples
+    /// ```rust, no_run
+    /// use rollo::server::SocketTools;
+    ///
+    /// fn on_message(socket: SocketTools) {
+    ///     let latency = socket.get_latency();
+    /// }
+    /// ```
     pub fn get_latency(&self) -> i64 {
         self.latency.load(Ordering::Acquire)
     }
 
     #[cfg(feature = "flatbuffers_helpers")]
     pub fn send_flatbuffers<
-        F: 'static + Fn(&mut FlatBufferBuilder<'static>) -> Result<Bytes, Error> + Send + Sync,
+        F: 'static + Fn(&mut FlatBufferBuilder<'static>) -> Result<Bytes> + Send + Sync,
     >(
         &self,
         f: F,
@@ -96,20 +122,51 @@ impl SocketTools {
     }
 
     /// Close the session
-    pub fn close(&self) -> Result<(), Error> {
+    /// ## Examples
+    /// ```rust, no_run
+    /// use rollo::server::SocketTools;
+    ///
+    /// fn on_message(socket: SocketTools) {
+    ///     if socket.close().is_err() {
+    ///         println!("Error when closing the session");
+    ///     }
+    /// }
+    /// ```
+    pub fn close(&self) -> Result<()> {
         self.tx
             .send(WriterMessage::Close)
             .map_err(|_| Error::Channel)
     }
 
     /// Close the session with a delay
-    pub fn close_with_delay(&self, delay: Duration) -> Result<(), Error> {
+    /// ## Examples
+    /// ```rust, no_run
+    /// use rollo::server::SocketTools;
+    /// use std::time::Duration;
+    ///
+    /// fn on_message(socket: SocketTools) {
+    ///     if socket.close_with_delay(Duration::from_secs(1)).is_err() {
+    ///         println!("Error when closing the session");
+    ///     }
+    /// }
+    /// ```
+    pub fn close_with_delay(&self, delay: Duration) -> Result<()> {
         self.tx
             .send(WriterMessage::CloseDelayed(delay))
             .map_err(|_| Error::Channel)
     }
 
     /// Is connection close ?
+    /// ## Examples
+    /// ```rust, no_run
+    /// use rollo::server::SocketTools;
+    ///
+    /// fn on_message(socket: SocketTools) {
+    ///     if socket.is_closed() {
+    ///     // Do something
+    ///     }
+    /// }
+    /// ```
     pub fn is_closed(&self) -> bool {
         self.tx.is_closed()
     }
