@@ -8,11 +8,7 @@ use async_trait::async_trait;
 use rollo::{
     error::Error,
     packet::Packet,
-    server::{
-        world::World,
-        world_session::{SocketTools, WorldSession},
-        world_socket_mgr::{ListenerSecurity, WorldSocketMgr},
-    },
+    server::{ListenerSecurity, SocketTools, World, WorldSession, WorldSocketMgr},
 };
 use rollo_macros::world_time;
 use tokio::{io::AsyncReadExt, net::TcpStream, task::JoinHandle, time::sleep};
@@ -37,7 +33,7 @@ async fn connect_server() {
 
 async fn setup(port: u32) -> JoinHandle<()> {
     let world = Box::new(MyWorld {
-        elapsed: AtomicI64::new(0),
+        time: AtomicI64::new(0),
     });
     let world = Box::leak(world);
     let mut server = WorldSocketMgr::new(world);
