@@ -4,11 +4,7 @@ use bytes::{BufMut, BytesMut};
 use rollo::{
     error::Error,
     packet::Packet,
-    server::{
-        world::World,
-        world_session::{SocketTools, WorldSession},
-        world_socket_mgr::{ListenerSecurity, WorldSocketMgr},
-    },
+    server::{ListenerSecurity, SocketTools, World, WorldSession, WorldSocketMgr},
 };
 use rollo_macros::world_time;
 use std::{
@@ -52,7 +48,7 @@ fn packet() -> BytesMut {
 
 async fn setup(port: u32) -> JoinHandle<()> {
     let world = Box::new(MyWorld {
-        elapsed: AtomicI64::new(0),
+        time: AtomicI64::new(0),
     });
     let world = Box::leak(world);
 
@@ -87,6 +83,9 @@ impl WorldSession<MyWorld> for MyWorldSession {
     }
 
     async fn on_message(world_session: &Arc<Self>, _world: &'static MyWorld, packet: Packet) {
+        assert!(packet.payload.is_some());
+        assert_eq!(6, packet.cmd);
+
         world_session
             .socket_tools
             .send(packet.cmd, Some(&packet.payload.unwrap()));
